// Datsun 240Z imsa GTU, GR-4
// V1.5

// Body including all rigidly attached parts (wings, barge boards, etc.)
[BODY]
name=body mass=(805.0) inertia=(833.0,933.0,152.0)
pos=(0.0,0.00,0.0) ori=(0.0,0.0,0.0)

// Front spindles
[BODY]
name=fl_spindle mass=(18.0) inertia=(0.0275,0.0260,0.0245)
pos=(0.724,0.0,-1.65) ori=(0.0,0.0,0.0)

[BODY]
name=fr_spindle mass=(18.0) inertia=(0.0275,0.0260,0.0245)
pos=(-0.724,0.0,-1.65) ori=(0.0,0.0,0.0)

// Front wheels
[BODY]
name=fl_wheel mass=(25.0) inertia=(2.250,1.000,1.000)
pos=(0.724,0.0,-1.65) ori=(0.0,0.0,0.0)

[BODY]
name=fr_wheel mass=(25.0) inertia=(2.250,1.000,1.000)
pos=(-0.724,0.0,-1.65) ori=(0.0,0.0,0.0)

// Rear spindles
[BODY]
name=rl_spindle mass=(22.0) inertia=(0.0358,0.0338,0.0319)
pos=(0.733,0.0,1.35) ori=(0.0,0.0,0.0)

[BODY]
name=rr_spindle mass=(22.0) inertia=(0.0358,0.0338,0.0319)
pos=(-0.733,0.0,1.35) ori=(0.0,0.0,0.0)

// Rear wheels (includes half of rear-axle)
[BODY]
name=rl_wheel mass=(29.0) inertia=(2.650,1.160,1.160)
pos=(0.733,0.0,1.35) ori=(0.0,0.0,0.0)

[BODY]
name=rr_wheel mass=(29.0) inertia=(2.650,1.160,1.160)
pos=(-0.733,0.0,1.35) ori=(0.0,0.0,0.0)

// Fuel in tank is not rigidly attached - it is attached with springs and
// dampers to simulate movement.  Properties are defined in the HDV file.

[BODY]
name=fuel_tank mass=(1.0) inertia=(1.0,1.0,1.0)
pos=(0.0,0.0,0.0) ori=(0.0,0.0,0.0)

// Driver's head is not rigidly attached, and it does NOT affect the vehicle
// physics.  Position is from the eyepoint defined in the VEH file, while
// other properties are defined in the head physics file.

[BODY]
name=driver_head mass=(5.0) inertia=(0.02,0.02,0.02)
pos=(0.0,0.0,0.0) ori=(0.0,0.0,0.0)


//////////////////////////////////////////////////////////////////////////
//
// Constraints
//
///////////////////////////////////////////////////////////////////////////////////////////////////
//Simulated Strut Suspension
// Front wheel and spindle connections
[JOINT&HINGE]
posbody=fl_wheel negbody=fl_spindle pos=fl_wheel axis=(-0.745,0.0,0.0)

[JOINT&HINGE]
posbody=fr_wheel negbody=fr_spindle pos=fr_wheel axis=(0.745,0.0,0.0)

// Front left suspension (2 A-arms + 1 steering arm = 5 links)
[BAR] // forward upper arm
name=fl_fore_upper posbody=body negbody=fl_spindle pos=(0.330,0.288,-1.65) neg=(0.533,0.328,-1.650)

[BAR] // rearward upper arm
posbody=body negbody=fl_spindle pos=(0.330,0.288,-1.45) neg=(0.533,0.328,-1.650)

[BAR] // forward lower arm
posbody=body negbody=fl_spindle pos=(0.320,-0.160,-1.65) neg=(0.648,-0.160,-1.65)

[BAR] // rearward lower arm
name=fl_fore_lower posbody=body negbody=fl_spindle pos=(0.320,-0.160,-1.40) neg=(0.648,-0.160,-1.65)

[BAR] // steering arm (must be named for identification)
name=fl_steering posbody=body negbody=fl_spindle pos=(0.292,-0.104,-1.815) neg=(0.600,-0.088,-1.822)

//////////////////////////////////////////////////////////////////////////////////////////////////////

// Front right suspension (2 A-arms + 1 steering arm = 5 links)
[BAR] // forward upper arm (used in steering lock calculation)
name=fr_fore_upper posbody=body negbody=fr_spindle pos=(-0.330,0.288,-1.65) neg=(-0.533,0.328,-1.650)

[BAR] // rearward upper arm
posbody=body negbody=fr_spindle pos=(-0.330,0.288,-1.45) neg=(-0.533,0.328,-1.650)

[BAR] // forward lower arm
name=fr_fore_lower posbody=body negbody=fr_spindle pos=(-0.320,-0.160,-1.65) neg=(-0.648,-0.160,-1.65)

[BAR] // rearward lower arm
posbody=body negbody=fr_spindle pos=(-0.320,-0.160,-1.40) neg=(-0.648,-0.160,-1.65)

[BAR] // steering arm (must be named for identification)
name=fr_steering posbody=body negbody=fr_spindle pos=(-0.292,-0.104,-1.815) neg=(-0.600,-0.088,-1.822)

///////////////////////////////////////////////////////////////////////////////////////////////////////

//Simulated Strut Rear Suspension
// Rear left suspension (2 A-arms + 1 Tie Rod = 5 links)
[BAR] // forward upper arm
posbody=body negbody=rl_spindle pos=(0.330,0.288,1.250) neg=(0.533,0.328,1.350)

[BAR] // rearward upper arm
posbody=body negbody=rl_spindle pos=(0.330,0.288,1.450) neg=(0.533,0.328,1.350)

[BAR] // forward lower arm
posbody=body negbody=rl_spindle pos=(0.220,-0.140,1.250) neg=(0.648,-0.160,1.250)

[BAR] // rearward lower arm
posbody=body negbody=rl_spindle pos=(0.220,-0.140,1.450) neg=(0.648,-0.160,1.250)

[BAR] // Tie Rod
posbody=body negbody=rl_spindle pos=(0.220,-0.140,1.450) neg=(0.648,-0.160,1.450)

//////////////////////////////////////////////////////////////////////////////////////////////////////

// Rear right suspension (2 A-arms + 1 Tie Rod = 5 links)
[BAR] // forward upper arm
posbody=body negbody=rr_spindle pos=(-0.330,0.288,1.250) neg=(-0.533,0.328,1.350)

[BAR] // rearward upper arm
posbody=body negbody=rr_spindle pos=(-0.330,0.288,1.450) neg=(-0.533,0.328,1.350)

[BAR] // forward lower arm
posbody=body negbody=rr_spindle pos=(-0.220,-0.140,1.250) neg=(-0.648,-0.160,1.250)

[BAR] // rearward lower arm
posbody=body negbody=rr_spindle pos=(-0.220,-0.140,1.450) neg=(-0.648,-0.160,1.250)

[BAR] // Tie Rod
posbody=body negbody=rr_spindle pos=(-0.220,-0.140,1.450) neg=(-0.648,-0.160,1.450)

////////////////////////////////////////////////////////////////////////////////////////////////////////

// Rear spindle and wheel connections
[JOINT&HINGE]
posbody=rl_wheel negbody=rl_spindle pos=rl_wheel axis=(-1.0,0.0,0.0)

[JOINT&HINGE]
posbody=rr_wheel negbody=rr_spindle pos=rr_wheel axis=(1.0,0.0,0.0)



